"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEventURL = void 0;
const moment_1 = __importDefault(require("moment"));
const qs_1 = __importDefault(require("qs"));
function randomId() {
    let n = Math.floor(Math.random() * 999999999999).toString();
    return new Date().getTime().toString() + "" + n;
}
function dateFormatter(date) {
    let formattedDate = moment_1.default.utc(date).format("YYYYMMDDTHHmmssZ");
    return formattedDate.replace("+00:00", "Z");
}
function calculateDuration(startTime, endTime) {
    const end = moment_1.default.utc(endTime).format("DD/MM/YYYY HH:mm:ss");
    const start = moment_1.default.utc(startTime).format("DD/MM/YYYY HH:mm:ss");
    const difference = moment_1.default(end, "DD/MM/YYYY HH:mm:ss").diff(moment_1.default(start, "DD/MM/YYYY HH:mm:ss"));
    return Math.floor(moment_1.default.duration(difference).asHours()) + moment_1.default.utc(difference).format(":mm");
}
function createEventURL(type, { startDate, endDate, location, title, details, eventUrl }) {
    const start = dateFormatter(startDate);
    const end = dateFormatter(endDate);
    switch (type) {
        case 'GOOGLE': {
            return `https://calendar.google.com/calendar/render?${qs_1.default.stringify({
                action: 'TEMPLATE',
                dates: start + '/' + end,
                location,
                text: title,
                details,
            })}`;
        }
        case 'OUTLOOKCOM': {
            return `https://outlook.live.com/owa/?${qs_1.default.stringify({
                rru: 'addevent',
                startdt: start,
                enddt: end,
                subject: title,
                location,
                body: details,
                allday: false,
                uid: randomId(),
                path: '/calendar/view/Month',
            })}`;
        }
        case 'YAHOO': {
            return `https://calendar.yahoo.com/?${qs_1.default.stringify({
                v: 60,
                view: 'd',
                type: 20,
                title,
                st: start,
                dur: calculateDuration(startDate, endDate),
                desc: details,
                in_loc: location,
            })}`;
        }
        case 'ICS': {
            return [
                "BEGIN:VCALENDAR",
                "VERSION:2.0",
                "BEGIN:VEVENT",
                "URL:" + eventUrl,
                "DTSTART:" + start,
                "DTEND:" + end,
                "SUMMARY:" + title,
                "DESCRIPTION:" + details,
                "LOCATION:" + location,
                "END:VEVENT",
                "END:VCALENDAR"
            ].join("\n");
        }
        default:
            break;
    }
}
exports.createEventURL = createEventURL;
